#' @import data.table
#' @import checkmate
#' @import paradox
#' @import mlr3misc
#' @import mlr3
#' @import bbotk
#' @import mlr3pipelines
#' @importFrom R6 R6Class
#' @importFrom utils combn head tail
"_PACKAGE"

.onLoad = function(libname, pkgname) {
  # nocov start
  assign("lg", lgr::get_logger("bbotk"),
    envir = parent.env(environment()))
  if (Sys.getenv("IN_PKGDOWN") == "true") {
    lg$set_threshold("warn")
  }
} # nocov end

leanify_package()
